SpeedTestDart class
A Speed tester.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createTestUrl(
Server server, String file) → Uri - Creates Uri from Server and String file
-
generateDownloadUrls(
Server server, int retryCount, List< FileSize> downloadSizes) → List<String> - Returns urls for download test.
-
generateUploadData(
int retryCount) → List< String> - Generate list of String urls for upload.
-
getBestServers(
{required List< Server> servers, int retryCount = 2, int timeoutInSeconds = 1}) → Future<List< Server> > - Returns a ListServer with the best servers, ordered by lowest to highest latency.
-
getSettings(
) → Future< Settings> - Returns Settings from speedtest.net.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
testDownloadSpeed(
{required List< Server> servers, int simultaneousDownloads = 2, int retryCount = 3, List<FileSize> downloadSizes = defaultDownloadSizes}) → Future<SpeedTestResult> - Returns SpeedTestResult server test, downloaded speed in MB/s.
-
testUploadSpeed(
{required List< Server> servers, int simultaneousUploads = 4, int retryCount = 4}) → Future<SpeedTestResult> - Returns SpeedTestResult server test, upload speed in MB/s.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited